#[non_exhaustive]pub enum CoordinateRangeErrorKind {
LineOutOfRange,
ColumnOutOfRange,
}Expand description
Failure kind when resolving a line and byte column in a LineIndex.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LineOutOfRange
Requested line is past the source line count.
ColumnOutOfRange
Requested byte column is past the end column for its line.