pub struct CoordinateRangeError { /* private fields */ }Expand description
Error returned when a source coordinate is outside a LineIndex.
Implementations
Sourceimpl CoordinateRangeError
impl CoordinateRangeError
Sourcepub const fn line(&self) -> LineNumber
pub const fn line(&self) -> LineNumber
Requested 1-based line number.
Sourcepub const fn byte_column(&self) -> ByteColumn
pub const fn byte_column(&self) -> ByteColumn
Requested 1-based byte column.
Sourcepub const fn source_line_count(&self) -> LineNumber
pub const fn source_line_count(&self) -> LineNumber
Number of lines known to the LineIndex.
Sourcepub const fn max_byte_column(&self) -> Option<ByteColumn>
pub const fn max_byte_column(&self) -> Option<ByteColumn>
Last valid 1-based byte column on the requested line, when the line exists.
Sourcepub const fn kind(&self) -> CoordinateRangeErrorKind
pub const fn kind(&self) -> CoordinateRangeErrorKind
Specific reason coordinate resolution failed.