pub struct ParserSpanToTextRangeError { /* private fields */ }Expand description
Error returned when a parser span cannot be converted to a TextRange.
Implementations
Sourceimpl ParserSpanToTextRangeError
impl ParserSpanToTextRangeError
Sourcepub const fn source_len_bytes(&self) -> ByteOffset
pub const fn source_len_bytes(&self) -> ByteOffset
Length of the source string the span was checked against.
Sourcepub const fn span_start(&self) -> ByteOffset
pub const fn span_start(&self) -> ByteOffset
Inclusive start byte offset from the parser span.
Sourcepub const fn span_end(&self) -> ByteOffset
pub const fn span_end(&self) -> ByteOffset
Exclusive end byte offset from the parser span.
Sourcepub const fn kind(&self) -> ParserSpanToTextRangeErrorKind
pub const fn kind(&self) -> ParserSpanToTextRangeErrorKind
Specific reason the conversion failed.