pub fn try_parser_span_to_text_range(
source: &str,
span: Span,
) -> Result<TextRange, ParserSpanToTextRangeError>Expand description
Try to convert a parser span into a text-size byte range.
This is the fallible API and should be used for spans sourced outside
SourceFile where invalid offsets are possible; offsets must be valid
UTF-8 character boundaries.